@@ -58,10 +58,11 @@ def multifunc(data,axisref,deffunc):
             dataouttrns = dataouttrns*eshapeout
         dataouttrns = array([dataouttrns])
         dataouttrns.shape = shapeout
-    scandata(datatrns,trnsaxisref,deffunc,dataouttrns)
+    dataouttrns = scandata(datatrns,trnsaxisref,deffunc,dataouttrns)
 
     # # old version
     # dataouttrns = scandata(0,datatrns,trnsaxisref,deffunc)
+    print(dataouttrns)
 
     print('data processing ended')
     
